import { Column, CreateDateColumn, Entity, ManyToOne, OneToMany, PrimaryGeneratedColumn } from "typeorm";
import { equipment } from "./equipment/equipment";
import { wearable } from "./wearable/wearable";
import { vehicle } from "./vehicle/vehicle";
import { damageReport } from "./damageReport";

@Entity()
export class maintenance {
  @PrimaryGeneratedColumn("uuid")
  id: string;

  @CreateDateColumn()
  createdAt: Date;

  @Column({ type: "varchar", length: 255 })
  status: string;

  @Column({ type: "boolean", default: false })
  done: boolean;

  @Column({ type: "text" })
  description: string;

  @Column({ nullable: true, default: null })
  equipmentId?: string;

  @Column({ nullable: true, default: null })
  vehicleId?: string;

  @Column({ nullable: true, default: null })
  wearableId?: string;

  @ManyToOne(() => equipment, (e) => e.maintenances, {
    nullable: true,
    onDelete: "CASCADE",
    onUpdate: "RESTRICT",
  })
  equipment?: equipment;

  @ManyToOne(() => vehicle, (v) => v.maintenances, {
    nullable: true,
    onDelete: "CASCADE",
    onUpdate: "RESTRICT",
  })
  vehicle?: vehicle;

  @ManyToOne(() => wearable, (w) => w.maintenances, {
    nullable: true,
    onDelete: "CASCADE",
    onUpdate: "RESTRICT",
  })
  wearable?: wearable;

  @OneToMany(() => damageReport, (dr) => dr.maintenance)
  reports: damageReport[];
}
